@@ -2,7 +2,7 @@
 A type-safe strictly defined structures, compatible with JSON draft 4
 but offers significantly more functionality.
 """
-from typedpy.structures import (
+from typedpy_libs.structures import (
     Structure,
     Field,
     TypedField,
@@ -14,17 +14,16 @@ from typedpy.structures import (
     ImmutableField,
     unique,
     AbstractStructure,
-)
-
-from typedpy.structures_reuse import (
     Partial,
     AllFieldsRequired,
     Omit,
     Pick,
     Extend,
+    keys_of,
 )
 
-from typedpy.fields import (
+
+from typedpy_libs.fields import (
     Number,
     Integer,
     PositiveInt,
@@ -44,6 +43,8 @@ from typedpy.fields import (
     String,
     SizedString,
     Sized,
+    Enum,
+    EnumString,
     AllOf,
     AnyOf,
     OneOf,
@@ -66,35 +67,37 @@ from typedpy.fields import (
     ImmutableNumber,
     ImmutableDeque,
     Deque,
+    SubClass,
     ExceptionField,
     Generator,
+    FunctionCall,
 )
 
-from typedpy.json_schema_mapping import (
+from typedpy_libs.json_schema.json_schema_mapping import (
     structure_to_schema,
     schema_to_struct_code,
     schema_definitions_to_code,
     write_code_from_schema,
 )
 
-from .enum import Enum, EnumString
 
-from .serialization import (
-    deserialize_structure,
-    serialize,
+from typedpy_libs.serialization import (
+    Serializer,
+    Deserializer,
+    deserializer_by_discriminator,
+    convert_dict,
+    Versioned,
+    mappers,
+    Deleted,
+    DoNotSerialize,
     serialize_field,
-    FunctionCall,
+    serialize,
+    deserialize_structure,
     deserialize_single_field,
     HasTypes,
 )
 
-from .serialization_wrappers import (
-    Serializer,
-    Deserializer,
-    deserializer_by_discriminator,
-)
-
-from .extfields import (
+from typedpy_libs.extfields import (
     DateString,
     DateField,
     DateTime,
@@ -105,7 +108,12 @@ from .extfields import (
     EmailAddress,
 )
 
-from .subclass import SubClass
+from typedpy_libs.stubs import (
+    create_pyi,
+    create_stub_for_file,
+    create_stub_for_file_using_ast,
+)
+
 
 from .errors import (
     standard_readable_error_for_typedpy_exception,
@@ -115,9 +123,6 @@ from .errors import (
 
 from .utility import get_list_type, type_is_generic
 
-from .mappers import mappers, Deleted, DoNotSerialize
-
-from .versioned_mapping import convert_dict, Versioned
 
 from .commons import (
     nested,
@@ -128,6 +133,3 @@ from .commons import (
     InvalidStructureErr,
     Constant,
 )
-
-from .keysof import keys_of
-from .type_helpers import create_pyi
